Deep Intelligence SDK for Python documentation
=============================================

.. image:: https://deepint.net/sites/default/files/logo2.svg
    :align: center

deepint is a python package to work with `Deep Intelligence <https://deepint.net/>`_ in a more easy and intuitive way, allowing the programmer to develop in a fast way the data, analisys and visualization flows.
The package consists in a wrapper arround `Deep Intelligence API <https://app.deepint.net/api/v1/documentation/>`_, with some extra facilities:

.. toctree::
   :maxdepth: 1

   ../_info/authentication.rst
   ../_info/date_formats.rst
   ../_info/usage.rst
   ../_info/api.rst


Deep Intelligence 
-----------------
Deep Intelligence has been designed to help you select optimal AI & Machine Learning algorithms for the analysis of your business’ datasets. This platform can be customized to read any type of data from webs, files, databases and sensors  among others. It can also stream data in real time if needed, it’s all very simple!

A highly attractive, user-friendly and intuitive visualization environment will guide you in the creation and configuration of algorithms that will analyze your data optimally. The platform makes it possible to create dashboards for better visualization experience, moreover, they can be easily integrated into any other online application. Improve your business decision-making without any expert IT knowledge!

Deep Intelligence is a platform for Fintech, IoT, Smart Cities, Smart Grids, Biomedical analysis, Logistics, Industry 4.0, etc. Some of our customers have already increased their business’ profits by 50%!

Our extensive team of data analysis experts will be at your complete disposal for any information, guidance and support you may need.

Visit the Deep Intelligence on it's `website <https://deepint.net/>`_.


Installation 
------------
You can install the package in multiple ways

* via Python Package Indexer (PyPI)::

    $ python -m pip install deepint

* from GitHub via PyPI::

    $ python -m pip install https://github.com/deepintdev/deepint-python-SDK/archive/master.zip


FAQ 
---
* **Q**: How do I authenticate or obtain a token? **A**: Visit the `authentication <_info/authentication.html>`_ section to learn how token can be obtained and providen.
* **Q**: How do I create and update a source? or How can I retrieve data from a Source or train a model? **A**: Visit the `usage <_info/usage.html>`_ section to learn the basics.


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Disclaimer 
------------
Deep Intelligence SDK for Python © Copyright 2021 by Deep Intelligence. All rights reserved.
